==> sox-14.1.0.tar.gz: sox-14.1.0/src/soxconfig.h.cmake <==
#define PACKAGE_VERSION "14.1.0"

#cmakedefine EXTERNAL_GSM             1
#cmakedefine HAVE_ALSA                1
#cmakedefine HAVE_AMRNB               1
#cmakedefine HAVE_AMRWB               1
#cmakedefine HAVE_BYTESWAP_H          1
#cmakedefine HAVE_FFMPEG              1
#cmakedefine HAVE_FLAC                1
#cmakedefine HAVE_FSEEKO              1
#cmakedefine HAVE_GETTIMEOFDAY        1
#cmakedefine HAVE_ID3TAG              1
#cmakedefine HAVE_INTTYPES_H          1
#cmakedefine HAVE_IO_H                1
#cmakedefine HAVE_LAME_LAME_H         1
#cmakedefine HAVE_LIBAO               1
#cmakedefine HAVE_LTDL_H              1
#cmakedefine HAVE_MACHINE_SOUNDCARD_H 1
#cmakedefine HAVE_MAD_H               1
#cmakedefine HAVE_OGG_VORBIS          1
#cmakedefine HAVE_POPEN               1
#cmakedefine HAVE_PNG                 1
#cmakedefine HAVE_SAMPLERATE_H        1
#cmakedefine HAVE_SNDFILE_1_0_12      1
#cmakedefine HAVE_SNDFILE_H           1
#cmakedefine HAVE_STDINT_H            1
#cmakedefine HAVE_STRCASECMP          1
#cmakedefine HAVE_STRINGS_H           1
#cmakedefine HAVE_STRING_H            1
#cmakedefine HAVE_STRRSTR             1
#cmakedefine HAVE_SUN_AUDIOIO_H       1
#cmakedefine HAVE_SYS_AUDIOIO_H       1
#cmakedefine HAVE_SYS_SOUNDCARD_H     1
#cmakedefine HAVE_SYS_TIMEB_H         1
#cmakedefine HAVE_SYS_TIME_H          1
#cmakedefine HAVE_SYS_TYPES_H         1
#cmakedefine HAVE_UNISTD_H            1
#cmakedefine HAVE_VSNPRINTF           1
#cmakedefine HAVE_WAVPACK             1
#cmakedefine WORDS_BIGENDIAN          1

==> sox_14.2.0.orig.tar.gz: sox-14.2.0/src/soxconfig.h.cmake <==
#define PACKAGE_VERSION "14.2.0"

#cmakedefine EXTERNAL_GSM             1
#cmakedefine HAVE_ALSA                1
#cmakedefine HAVE_AMRNB               1
#cmakedefine HAVE_AMRWB               1
#cmakedefine HAVE_BYTESWAP_H          1
#cmakedefine HAVE_FFMPEG              1
#cmakedefine HAVE_FLAC                1
#cmakedefine HAVE_FSEEKO              1
#cmakedefine HAVE_GETTIMEOFDAY        1
#cmakedefine HAVE_ID3TAG              1
#cmakedefine HAVE_INTTYPES_H          1
#cmakedefine HAVE_IO_H                1
#cmakedefine HAVE_LAME_LAME_H         1
#cmakedefine HAVE_LIBAO               1
#cmakedefine HAVE_LTDL_H              1
#cmakedefine HAVE_MACHINE_SOUNDCARD_H 1
#cmakedefine HAVE_MAD_H               1
#cmakedefine HAVE_MP3                 1
#cmakedefine HAVE_MAGIC               1
#cmakedefine HAVE_OGG_VORBIS          1
#cmakedefine HAVE_POPEN               1
#cmakedefine HAVE_PNG                 1
#cmakedefine HAVE_SAMPLERATE_H        1
#cmakedefine HAVE_SNDFILE_1_0_12      1
#cmakedefine HAVE_SNDFILE             1
#cmakedefine HAVE_STDINT_H            1
#cmakedefine HAVE_STRCASECMP          1
#cmakedefine HAVE_STRINGS_H           1
#cmakedefine HAVE_STRING_H            1
#cmakedefine HAVE_STRRSTR             1
#cmakedefine HAVE_SUN_AUDIOIO_H       1
#cmakedefine HAVE_SYS_AUDIOIO_H       1
#cmakedefine HAVE_SYS_SOUNDCARD_H     1
#cmakedefine HAVE_SYS_TIMEB_H         1
#cmakedefine HAVE_SYS_TIME_H          1
#cmakedefine HAVE_SYS_TYPES_H         1
#cmakedefine HAVE_SYS_UTSNAME_H       1
#cmakedefine HAVE_UNISTD_H            1
#cmakedefine HAVE_VSNPRINTF           1
#cmakedefine HAVE_WAVPACK             1
#cmakedefine WORDS_BIGENDIAN          1
